% durablesVAR_run.m
%
% Main file to run and plot Figure 3 of the the durables replacement model.
%
% SVAR analysis of durables with respect to monetary shocks
%
%------------------------------------------------------------------
% SVAR replication code for "The role of durables replacement and
% second-hand markets in a business-cycle model" 
%------------------------------------------------------------------
% Data: QuarterlyDurableVAR.xlsx
% Reduced-form VAR estimation: varestboot1.m
% Impulse response calculation: ir_varboot1.m
% Run and plot file: durablesVAR_run.m
% Supporting codes: shadedplot.m, tornqvist1.m
%------------------------------------------------------------------
%
% December 2018, Hyunseung Oh (E-mail: hyunseungoh@gmail.com)




% Step 1: Import the file
fileToRead1 = 'QuarterlyDurableVAR.xlsx'; % chained 2005 dollars (real data)
sheetName = 'Data';
[numbers, strings, raw] = xlsread(fileToRead1, sheetName);
newData1.data =  numbers;
newData1.colheaders = strings(1,:);
% Create new variables in the base workspace from those fields.
for i = 1:size(newData1.colheaders, 2)
    assignin('base', genvarname(newData1.colheaders{i}), newData1.data(:,i));
end
clear fileToRead1 sheetName numbers strings raw newData1

% Step 2: VAR analysis
index = (Date >= 1967).*(Date <= 2007.75);
index = logical(index);


% construct nondurables and services series
RNDS     = tornqvist1(PCE./PricePCE,Durable./PriceDurable,PCE,Durable,'minus');
PriceNDS = tornqvist1(PricePCE,PriceDurable,PCE,Durable,'minus');

% Define inflation
InflationGDP         = diff(log(PriceGDP));
InflationPCE         = diff(log(PricePCE));
InflationNON         = diff(log(PriceNondurable));
InflationSER         = diff(log(PriceServices));
InflationDUR         = diff(log(PriceDurable));
InflationNM          = diff(log(PriceNewMotor));
InflationNA          = diff(log(PriceNewAuto));
InflationNT          = diff(log(PriceNewTruck));
InflationUA          = diff(log(PriceUsedAutoMargin));
InflationUT          = diff(log(PriceUsedTruckMargin));
InflationNDS         = diff(log(PriceNDS));

% Index inflation
InflationGDP         = InflationGDP(index);
InflationPCE         = InflationPCE(index);
InflationNON         = InflationNON(index);
InflationSER         = InflationSER(index);
InflationDUR         = InflationDUR(index);
InflationNM          = InflationNM(index);
InflationNA          = InflationNA(index);
InflationNT          = InflationNT(index);
InflationUA          = InflationUA(index);
InflationUT          = InflationUT(index);
InflationNDS         = InflationNDS(index);

% Index nominal quantity
GDP                  = GDP(index);
PCE                  = PCE(index);
Nondurable           = Nondurable(index);
Services             = Services(index);
Durable              = Durable(index);
NewMotor             = NewMotor(index);
NewAuto              = NewAuto(index);
NewTruck             = NewTruck(index);
UsedAutoMargin       = UsedAutoMargin(index);
UsedTruckMargin      = UsedTruckMargin(index);

% Index real quantity
RNDS                 = RNDS(index);

% Index price index
PriceGDP             = PriceGDP(index);
PricePCE             = PricePCE(index);
PriceNondurable      = PriceNondurable(index);
PriceServices        = PriceServices(index);
PriceDurable         = PriceDurable(index);
PriceNewMotor        = PriceNewMotor(index);
PriceNewAuto         = PriceNewAuto(index);
PriceNewTruck        = PriceNewTruck(index);
PriceUsedAutoMargin  = PriceUsedAutoMargin(index);
PriceUsedTruckMargin = PriceUsedTruckMargin(index);
PriceNDS             = PriceNDS(index);

% Index Fed Funds Rate (end-of-period)
FFR                  = FFR(index);


%------------------------------------------------
% VAR ESTIMATION SETUP
%------------------------------------------------
% slow variable to fast variable

x1 = 100*log(RNDS);
x1_title = 'Nondurable Expenditure';
x2 = 100*log(NewMotor./PriceNewMotor);
x2_title = 'New Vehicle Expenditure';
x3 = 100*log(UsedAutoMargin./PriceUsedAutoMargin);
x3_title = 'Used Auto Dealers Margin';
x4 = 100*(InflationNM-InflationNDS);
x4_title = 'New Vehicle Relative Inflation';
x5 = 100*(InflationNDS);
x5_title = 'Nondurable Inflation';
x6 = FFR;
x6_title = 'Federal Funds Rate';
X = [x1 x2 x3 x4 x5 x6];

p = 4; % VAR(p) : number of lags
shock = [0 0 0 0 0 0.25]; % shock for IRF
[result]=varestboot1(X,p);
nvar = size(X,2);

% short-run
A0 = chol(result.Omega,'lower'); % lower triangular restriction
for j=1:nvar
    A0(j,:) = A0(j,:)/A0(j,j);
end
B0 = eye(nvar);

% IRF analysis 
Comp = result.Comp;
Compboot = result.Compboot;
h = 21; % horizon

[IRF IRFupper IRFlower MSEhi]=ir_varboot1(Comp,A0,B0,shock,h,Compboot,0.90);



%% PLOT FIGURE

p1 = 2; p2 = 3; fs = 10;
col = 'k';
col_line = [0.6 0.6 0.6];

graphname  = 'fig3';
ylabelname = 'Percent';
xlabelname = 'Period';

f1 = figure; % Set figure number for display

% Figure configuration
set(gcf, 'PaperUnits', 'inches') 
set(gcf, 'PaperOrientation', 'landscape');
papersize = get(gcf, 'PaperSize');
%------------- User configuration -------------%
width  = 8;  % Initialize a variable for width
height = 5;   % Initialize a variable for height
%----------------------------------------------%
bottom = (papersize(2)- height)/2;
left = (papersize(1)- width)/2;
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);


subplot(p1,p2,2)
shadedplot([0:h-1],[IRFlower(:,1)]',[IRFupper(:,1)]',[0.7 0.7 0.7],[0.7 0.7 0.7]);
hold on;
plot(0:h-1,zeros(h,1),'k')
plot(0:h-1,[(IRF(:,1))],'Color',col,'LineWidth',3);
grid on; box on;
title(x1_title,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex')
%ylim([-1.0 0.5])
set(gca,'XTick',[0:4:20]) % X tick data to plot
ylabel(ylabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');
xlabel(xlabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');

subplot(p1,p2,1)
shadedplot([0:h-1],[IRFlower(:,2)]',[IRFupper(:,2)]',[0.7 0.7 0.7],[0.7 0.7 0.7]);
hold on;
plot(0:h-1,zeros(h,1),'k')
plot(0:h-1,[(IRF(:,2))],'Color',col,'LineWidth',3);
grid on; box on;
title(x2_title,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex')
%ylim([-1.0 0.5])
set(gca,'XTick',[0:4:20]) % X tick data to plot
ylabel(ylabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');
xlabel(xlabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');


subplot(p1,p2,3)
shadedplot([0:h-1],[IRFlower(:,3)]',[IRFupper(:,3)]',[0.7 0.7 0.7],[0.7 0.7 0.7]);
hold on;
plot(0:h-1,zeros(h,1),'k')
plot(0:h-1,[(IRF(:,3))],'Color',col,'LineWidth',3);
grid on; box on;
title(x3_title,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex')
%ylim([-1.0 0.5])
set(gca,'XTick',[0:4:20]) % X tick data to plot
ylabel(ylabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');
xlabel(xlabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');


subplot(p1,p2,4)
shadedplot([0:h-1],[IRFlower(:,4)]',[IRFupper(:,4)]',[0.7 0.7 0.7],[0.7 0.7 0.7]);
hold on;
plot(0:h-1,zeros(h,1),'k')
plot(0:h-1,[(IRF(:,4))],'Color',col,'LineWidth',3);
grid on; box on;
title(x4_title,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex')
set(gca,'XTick',[0:4:20]) % X tick data to plot
ylabel(ylabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');
xlabel(xlabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');


subplot(p1,p2,5)
shadedplot([0:h-1],[IRFlower(:,5)]',[IRFupper(:,5)]',[0.7 0.7 0.7],[0.7 0.7 0.7]);
hold on;
plot(0:h-1,zeros(h,1),'k');
plot(0:h-1,[(IRF(:,5))],'Color',col,'LineWidth',3);
grid on; box on;
title(x5_title,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex')
set(gca,'XTick',[0:4:20]) % X tick data to plot
ylabel(ylabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');
xlabel(xlabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');


subplot(p1,p2,6)
shadedplot([0:h-1],[IRFlower(:,6)]',[IRFupper(:,6)]',[0.7 0.7 0.7],[0.7 0.7 0.7]);
hold on;
plot(0:h-1,zeros(h,1),'k');
plot(0:h-1,[(IRF(:,6))],'Color',col,'LineWidth',3);
grid on; box on;
title(x6_title,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex')
set(gca,'XTick',[0:4:20]) % X tick data to plot
ylabel(ylabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');
xlabel(xlabelname,'FontSize',fs,'FontWeight','Bold','Interpreter','Latex');


% Save plot
cd Plot % in a subfolder "\Plot"
print(f1,'-dpdf', [graphname]); 
print(f1,'-depsc2', [graphname]); 
cd ..
