function [IRF IRFupper IRFlower MSEhi]=ir_varboot1(Comp,A0,B0,shock,h,Compboot,ci)
% [IRF IRFupper IRFlower MSEhi]=ir_varboot1(Comp,A0,shock,h,Compboot,ci) 
%
%--------------------------------------------------------------------------
% A0*Y = BETA(1) + BETA*Ylag + B0*e
%    e ~ N(0,Identity)
%--------------------------------------------------------------------------
%
% 1. performs an h step ahead forecast (IRF) starting from the 
%    steady state with regards to a realization of a shock
% 2. computes the CI of the IRF by Kilian's bootstrap method
% 3. performs the variance decomposition for each period with regards 
%    to each variable (or fundamental shock)
%
% == Input:
% (Comp): Companion matrix of the form derived in varestboot1.m
% (A0): Structural matrix on variable 
% (B0): Structural matrix on structural shocks such that e ~ N(0,Identity)
% (shock): nvar by 1 vector of the shock to impose
% (h): maximum period to obtain IRF and VD
% (Compboot): Companion matrix of the bootstrap in varestboot1.m
% (ci): confidence interval region (default: 0.95)
% 
%
% == Output:
% (IRF): h by nvar matrix of impulse responses
% (MSEhi): h by nvar matrix of variance decomposition
% 
% Caution: It is important for variance decomposition that e~N(0,Identity)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Hyunseung Oh (ho2180@columbia.edu) Oct 7, 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nargin == 5
    ci = 0.95;
end

% 1. Impulse Response Function (IRF) 
%-----------------------------------------------------------%
m = length(Comp);        % square matrix
mm=find(Comp(end,:)==1);
if isempty(mm)
    mm=0;
end
nvar=m-mm;               % number of variables
nlag=m/nvar;             % number of lags

shock = shock(:);        % shock imposed
E = zeros(m,1);          % shock in companion form
E(1:nvar) = shock;       % impose shock

RR = zeros(m);           % structural matrix in companion form
RR(1:nvar,1:nvar)= A0\B0; % impose structural matrix

IRF = zeros(m,h);        % impulse response in companion form
IRF(:,1)= RR*E;       % 1st IRF with regards to shock
if h > 1
    for t=2:h            % 2nd to h_th IRF
        IRF(:,t)=Comp*IRF(:,t-1); 
    end
end
IRF = IRF(1:nvar,:);     % IRF in an easy form
IRF = IRF';              % IRF(h,nvar)
%-----------------------------------------------------------%

% 2. Bootstrap Confidence Intervals 
%-----------------------------------------------------------%
B = length(Compboot);
if h > 1
    IRFboot = cell(1,B);
    for b=1:B
        IRFboot{b} = zeros(m,h);
        IRFboot{b}(:,1) = RR*E;
        for t=2:h
            IRFboot{b}(:,t)=Compboot{b}*IRFboot{b}(:,t-1);
        end
    end

    IRFboots = zeros(m,B,h);
    for b=1:B
        for t=1:h
            IRFboots(:,b,t)=IRFboot{b}(:,t);
        end
    end
    IRFbootsort = zeros(nvar,B,h);
    IRFupper = zeros(nvar,h);
    IRFlower = zeros(nvar,h);
    for i=1:nvar
        for t=1:h
            IRFbootsort(i,1:B,t)=sort(IRFboots(i,:,t));
            IRFupper(i,t)=IRFbootsort(i,ceil((0.5+ci/2)*B),t);  
            IRFlower(i,t)=IRFbootsort(i,ceil((0.5-ci/2)*B),t); 
        end
    end
end
IRFupper = IRFupper';
IRFlower = IRFlower';
%-----------------------------------------------------------%

% 3. Variance decomposition 
%-----------------------------------------------------------%
JJ=zeros(nvar,m);
JJ(:,1:nvar)=eye(nvar);

% h variance decomposition
VD=zeros(nvar,nvar);
for t=1:h
    VD= VD + JJ*Comp^(t-1) * RR*(JJ*Comp^(t-1)*RR)';
end
MSEh=diag(VD);

SDi=zeros(m,m,nvar);
for i=1:nvar
    SDi(i,i,i) = 1;
end

VDi=zeros(nvar,nvar,nvar);
for i=1:nvar
    for t=1:h
        VDi(:,:,i)=VDi(:,:,i) + (JJ*Comp^(t-1)*RR)*SDi(:,:,i)*(JJ*Comp^(t-1)*RR)';
    end
end

[rowh colh]=size(MSEh);
MSEhi=zeros(rowh,colh,nvar);
for i=1:nvar
    MSEhi(:,:,i)=diag(VDi(:,:,i)) ./ MSEh;
end
MSEhi=squeeze(MSEhi);
%-----------------------------------------------------------%


