function z = tornqvist1(y,x,yn,xn,option)
% z = tornqvist1(y,x,yn,xn) 
% constructs the real series y net of x. Obviously, simply subtracting the
% series (i.e. z = y - x) does not have desirable properties. Hence, here
% we follow the Tornqvist method, suggested in Whelan (2003).
% 
% Input: 
% y  : total real chain-weighted series
% x  : real series desired to be subtracted out from y
% yn : nominal series of y
% xn : nominal series of x
% option: if option is 'sum', z = y + x is constructed!
%
% Output:
% z  : constructed real series
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Last revised: Sep 7, 2011
% Hyunseung Oh (ho2180@columbia.edu)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

T = length(y);

if nargin == 5 && strcmp(option,'sum')
    % construct z = y + x
    
    % theta: chain-weighted nominal share (t=2:T)
    theta = ( xn(2:end)./(xn(2:end) + yn(2:end)) + xn(1:end-1)./(xn(1:end-1) + yn(1:end-1)) )/2;

    % gry, grx: growth rate of y & x
    gry = (y(2:end) - y(1:end-1))./y(1:end-1);
    grx = (x(2:end) - x(1:end-1))./x(1:end-1);

    % Tornqvist method
    grz = (1-theta).*gry + theta.*grx;
    
    % recover the desired series z
    z = ones(T,1);
    for t = 2:T
        z(t) = z(t-1)*(1+grz(t-1));
    end
    
    disp('z = y + x is constructed')
    
else
    % theta: chain-weighted nominal share (t=2:T)
    theta = (xn(2:end)./yn(2:end) + xn(1:end-1)./yn(1:end-1))/2;

    % gry, grx: growth rate of y & x
    gry = (y(2:end) - y(1:end-1))./y(1:end-1);
    grx = (x(2:end) - x(1:end-1))./x(1:end-1);

    % Tornqvist method
    grz = (1./(1-theta)).*(gry - theta.*grx);
    
    % recover the desired series z
    z = ones(T,1);
    for t = 2:T
        z(t) = z(t-1)*(1+grz(t-1));
    end
    
    disp('z = y - x is constructed')
end