function [result]=varestboot1(X,p)
% [result] = varestboot1(X,p) 
% 
% returns the VAR results with data (X) in (p) lags where each column 
% BETA(:,i) represents the regression coefficient of the following VAR:
%-------------------------------------------------------------------------- 
% Y(:,i) = BETA(1,i)+BETA(2:n+1,i)*Ylag1(:,i)+BETA(n+2:2n+1,i)*Ylag2(:,i)
%          +...+BETA((p-1)n+2:pn+1,i)*Ylagp(:,i) + uhat(:,i)
%--------------------------------------------------------------------------
% This implies that at the first step, the data is fliped upside down since
% usually time series data come in an ascending form in terms of time 
% (from past to present).
% 
% For confidence interval computation , I use Kilian's method 
% (bootstrap in the bootstrap). The bias-corrected bootstrap companion
% matrices are computed, to be used in ir_varboot1.m 
% 
% == Input: 
% (X): data in an ascending form: last row is the most recent period
% (p): number of lags
% 
% == Output: result.
% (BETA): n*p+1 by n matrix where each column represents coefficients for
%         each variable
% (uhat): residual term where the first row is the most recent period
% (Omega): variance covariance matrix of uhat
% (Comp): companion matrix
% (Xud):  data fliped where the first row is the most recent period
% (Compboot): bootstrap companion matrix
% (B): number of bootstrap conducted
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Hyunseung Oh (ho2180@columbia.edu) Oct 7, 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[T nvar]=size(X); 
if nvar>T
    disp('Each column of X must be the time series')
    return
end

Xud=flipud(X); % so that the dataset now runs from recent to past

% Model: Y = BETA(0)*one + BETA(L)*Ylag + error
Y    = Xud(1:T-p,:);   % LHS of VAR
Ylag = cell(p,1);      % RHS of VAR
for i=1:p
    Ylag{i} = Xud(1+i:T-p+i,:);
end
% constant trend added
one = ones(T-p,1);
XX = one;
for i=1:p
    XX = [XX Ylag{i}]; % regressor
end
BETA = zeros(1+nvar*p,nvar); % coefficient
uhat = zeros(T-p,nvar);   % residual
for i=1:nvar
    BETA(:,i)=(XX'*XX)\(XX'*Y(:,i));
    uhat(:,i)=Y(:,i) - XX*BETA(:,i);
end
% variance-covariance matrix
Omega = (1/(T-p-nvar*p))*(uhat')*uhat;

% Construct companion matrix
BETA_0 = BETA(2:end,:); % BETA without constant (in the companion form)
Ident = [eye(nvar*(p-1)) zeros(nvar*(p-1),nvar)];
Comp = [BETA_0'; Ident];
    

% Bootstrap confidence intervals
rand('state',999);  % seed for random number
T_p = T-p;          % number of effective observations
B = 1000;           % number of resampling (Runkle)
B2= 100;            % bootstrap inside the bootstrap (Kilian)
Compboot = cell(1,B); 

Xboot = Y;
XXboot = XX;

for b=1:B
    % 1st step bootstrap
    resamp_index = ceil(T_p*rand(T_p,1));
    uboot=uhat(resamp_index,:);
    for i=1:nvar
        Xboot(end,i)=XXboot(end,:)*BETA(:,i)+uboot(end,i);
    end
    for t=2:T_p
        XXboot(end+1-t,1+1:1+nvar) = Xboot(end+2-t,:);
        if p>1
            XXboot(end+1-t,2+nvar:1+p*nvar) = XXboot(end+2-t,2:1+(p-1)*nvar);
        end
        for i=1:nvar
            Xboot(end+1-t,i) = XXboot(end+1-t,:)*BETA(:,i)+uboot(end+1-t,i);
        end
    end
    BETAboot = zeros(1+nvar*p,nvar);
    uhatboot = zeros(T_p,nvar);
    for i=1:nvar
        BETAboot(:,i)=inv(XXboot'*XXboot)*XXboot'*Xboot(:,i);
        uhatboot(:,i) = Xboot(:,i) - XXboot*BETA(:,i);
    end        
    
    % 2nd step bootstrap for bias-correction (bootstrap in a bootstrap)
    BETAboot2 = zeros(1+nvar*p,nvar,B2); % coefficients for bias correction
    for b2=1:B2
        resamp_index = ceil(T_p*rand(T_p,1));
        uhatboot2=uhatboot(resamp_index,:);
        for i=1:nvar
            Xboot(end,i)=XXboot(end,:)*BETAboot(:,i)+uhatboot2(end,i);
        end
        
        for t=2:T_p
            XXboot(end+1-t,1+1:1+nvar) = Xboot(end+2-t,:);
            if p>1
            XXboot(end+1-t,2+nvar:1+p*nvar) = XXboot(end+2-t,2:1+(p-1)*nvar);
            end
            for i=1:nvar
                Xboot(end+1-t,i) = XXboot(end+1-t,:)*BETAboot(:,i)+uhatboot2(end+1-t,i);
            end
        end
        
        for i=1:nvar
            BETAboot2(:,i,b2)=inv(XXboot'*XXboot)*XXboot'*Xboot(:,i);
        end        
    end
    
    % Bias correction
    BETAbias = mean(BETAboot2,3)-BETAboot; % bias for BETA
    BETAboot = BETAboot - BETAbias;        % bias-corrected estimate
    
    % Construct companion matrix
    BETAboot_0 = BETAboot(2:end,:); % BETA without constant (in the companion form)
    Identboot = [eye(nvar*(p-1)) zeros(nvar*(p-1),nvar)];
    Compboot{b} = [BETAboot_0'; Identboot];
end

% Output:
result.BETA  = BETA;
result.uhat  = uhat;
result.Omega = Omega;
result.Comp  = Comp;
result.Xud   = Xud;
result.Compboot = Compboot;
result.B = B; % number of resampling for bootstrap