function [fx,fxp,fy,fyp,fypyp,fypy,fypxp,fypx,fyyp,fyy,fyxp,fyx,fxpyp,fxpy,fxpxp, ...
    fxpx,fxyp,fxy,fxxp,fxx,f] = DurRep_model
% DurRep_model.m
%
% Equilibrium conditions of the durables replacement model, based on 
% Schmitt-Grohe and Uribe (2004).
%
%------------------------------------------------------------------
% Model replication code for "The role of durables replacement and
% second-hand markets in a business-cycle model" 
%------------------------------------------------------------------
% Equilibrium conditions: DurRep_model.m
% Steady state computation: DurRep_model_ss.m
% Run and plot file: DurRep_model_run.m
% Supporting codes from Schmitt-Grohe and Uribe (2004): anal_deriv.m,
% gx_hx.m, ir.m, mom.m, num_eval.m, gxx_hxx.m, simu_2nd.m
%------------------------------------------------------------------
%
% December 2018, Hyunseung Oh (E-mail: hyunseungoh@gmail.com)

ALPHA = sym('ALPHA');
BETA  = sym('BETA');
DELTA = sym('DELTA');
MCC   = sym('MCC');
PID   = sym('PID');
PIC   = sym('PIC');
pid   = sym('pid');
MU    = sym('MU');
mu    = sym('mu');

%Define parameters
syms 	EETA XI EPSIL PHI PSI_C PSI_D THE_C THE_D K
syms    RHO RHO_R RHO_Z TAU_P TAU_Y R c_r RHO_V RHO_B PI_S

%Define variables 
syms v  zz  rl  d  dnl  qql  qqrl  ssnl  c  c2  xx  dn  ssn  kc  kd  h  hc  hd  w  rk  r  qq  qqr  pic  piu  mcc0  mcd  muu  b ...
     vp zzp rlp dp dnlp qqlp qqrlp ssnlp cp c2p xxp dnp ssnp kcp kdp hp hcp hdp wp rkp rp qqp qqrp picp pidp piup mcc0p mcdp muup bp

syms V R D DN QQ QQR C C2 XX SSN KC KD KU H HC HD HU W RK R PIU MCC MCD


% Household FOC
f(1) = PHI*h*c - PSI_C*w;  % intratemporal EE
f(2) = picp*cp - BETA*(bp/b)*r*c; % intertemporal EE
f(3) = muu - PSI_D/dp - BETA*(1-DELTA)*(bp/b)*(ssnp*(qqp/qqrp)*(PSI_C/cp) + (1-ssnp)*muup);
f(4) = qq*(PSI_C/c) - muu - BETA*DELTA*(bp/b)*(1-RHO)*(ssnp*(qqp/qqrp)*(PSI_C/cp) + (1-ssnp)*muup);
f(5) = ((1-DELTA)*d + DELTA*(1-RHO)*dnl)*(muu - (qq/qqr)*(PSI_C/c)) +PI_S*((qq/qqr)*(PSI_C/c)*((1/2)*(ssn/ssnl-1)^2 + (ssn/ssnl)*(ssn/ssnl-1)) - BETA*(bp/b)*(qqp/qqrp)*(PSI_C/cp)*(ssnp/ssn)^2*(ssnp/ssn-1)); 
f(6) = dp - (1-ssn)*((1-DELTA)*d + DELTA*(1-RHO)*dnl) - dn; % durable accumulation function

% nondurable firm (intermediate)
f(7) = c + EPSIL*ssn*( (1-DELTA)*d + DELTA*(1-RHO)*dnl ) - zz*kc^EETA*hc^(1-EETA); % resource constraint (up to first order)
f(8) = mcc0 - w/((1-EETA)*zz*kc^EETA*hc^(-EETA));
f(9) = mcc0 - rk/(EETA*zz*kc^(EETA-1)*hc^(1-EETA));
f(10)= -log(pic/PIC) + BETA*log(picp/PIC) + (((1-ALPHA)*(1-ALPHA*BETA))/(ALPHA))*log(mcc0/MCC);

% durable firm (intermediate)
f(11)= xx - zz*kd^(EETA)*hd^(1-EETA);
f(12)= dn - ( ssn*((1-DELTA)*d + DELTA*(1-RHO)*dnl) + xx );
f(13)= mcd - w/((1-EETA)*zz*kd^EETA*hd^(-EETA));
f(14)= mcd - rk/(EETA*zz*kd^(EETA-1)*hd^(1-EETA));
f(15)= qq*( dn + (ssn/(THE_D-1))*((1-DELTA)*d+DELTA*(1-RHO)*dnl) ) - dn*(THE_D/(THE_D-1))*mcd;

% secondhand firm
f(16)= qqr - 1 - EPSIL*(qqr/qq);

% market clearing
f(17)= h - hc - hd;
f(18)= K - kc - kd;

% monetary policy (Taylor)
f(19)= log(r/R) - RHO_R.*log(rl/R) - (1-RHO_R).*(TAU_P.*(c_r.*log(pic/PIC) + (1-c_r).*log(pid/PID)) + TAU_Y.*(log(c/C)+log(dn/DN))) - log(v);
f(20)= log(vp) - RHO_V*log(v);

% technology shock
f(21)= log(zzp) - RHO_Z*log(zz);

% demand shock
f(22)= log(bp) - RHO_B*log(b);

% identity (lags and forwards)
f(23)= pid/pic - qq/qql;
f(24)= pid/piu - qqr/qqrl;
f(25)= rlp - r;
f(26)= dnlp - dn;
f(27)= qqlp - qq;
f(28)= qqrlp - qqr;
f(29)= ssnlp - ssn;
f(30)= c2 - (c + EPSIL*ssn*( (1-DELTA)*d + DELTA*(1-RHO)*dnl ));

%Create function f
f = f(:);


% Define the vector of controls, y, and states, x
x  = [v  zz  rl  d  dnl  qql  qqrl  ssnl  b];
y  = [c  c2  xx  dn  ssn  kc  kd  h  hc  hd  w  rk  r  qq  qqr  pic  pid  piu  mcc0  mcd  muu];
xp = [vp zzp rlp dp dnlp qqlp qqrlp ssnlp bp];
yp = [cp c2p xxp dnp ssnp kcp kdp hp hcp hdp wp rkp rp qqp qqrp picp pidp piup mcc0p mcdp muup];


%Make f a function of the logarithm of the state and control vector
f = subs(f, [x,y,xp,yp], exp([x,y,xp,yp]));


%Compute analytical derivatives of f
[fx,fxp,fy,fyp,fypyp,fypy,fypxp,fypx,fyyp,fyy,fyxp,fyx,fxpyp,fxpy,fxpxp,fxpx,fxyp,fxy,fxxp,fxx]=anal_deriv(f,x,y,xp,yp);