% DurRep_model_run.m
%
% Main file to run and plot Figure 4 of the the durables replacement model, 
% based on Schmitt-Grohe and Uribe (2004).
%
%------------------------------------------------------------------
% Model replication code for "The role of durables replacement and
% second-hand markets in a business-cycle model" 
%------------------------------------------------------------------
% Equilibrium conditions: DurRep_model.m
% Steady state computation: DurRep_model_ss.m
% Run and plot file: DurRep_model_run.m
% Supporting codes from Schmitt-Grohe and Uribe (2004): anal_deriv.m,
% gx_hx.m, ir.m, mom.m, num_eval.m, gxx_hxx.m, simu_2nd.m
%------------------------------------------------------------------
%
% December 2018, Hyunseung Oh (E-mail: hyunseungoh@gmail.com)


close all;

[fx,fxp,fy,fyp,fypyp,fypy,fypxp,fypx,fyyp,fyy,fyxp,fyx,fxpyp, ...
    fxpy,fxpxp,fxpx,fxyp,fxy,fxxp,fxx,f] = DurRep_model;

%Numerical Evaluation
%Steady State and Parameter Values
[EETA BETA DEL_D PSI_C ALPHA TAU_P TAU_Y RHO_R RHO_Z RHO_V RHO_B H K c_r EPSIL THE_C ...
    MCC MCD QQ QQR SSS DELTA RHO THE_D R PIC PID PIU KC KD HC HD C C2 XX D DN W RK PHI PSI_D MU V SSN ...
    v  zc  zd  rl  d  dnl  qql  qqrl  ssnl  c  c2  xx  dn  ssn  kc  kd  h  hc  hd  w  rk  r  qq  qqr  pic  pid  piu  mcc0  mcd  muu  b ...
    vp zcp zdp rlp dp dnlp qqlp qqrlp ssnlp cp c2p xxp dnp ssnp kcp kdp hp hcp hdp wp rkp rp qqp qqrp picp pidp piup mcc0p mcdp muup bp zz zzp]=DurRep_model_ss;


%Order of approximation desired 
approx = 1;


% Impulse response
T = 9; % time period
tg = 0.0025;  % target interest rate change
l_w  = 1.0; % line width
l_w2 = 2.0;  


% durable adjustment cost coefficient
adjcost = [0.005 1e+10]; % adjustment cost to consider


% Store IRFs
IR_x    = zeros(T,2); % new durable expenditure
IR_c    = zeros(T,2); % nondurable expenditure
IR_s    = zeros(T,2); % replacement ratio
IR_d_mu = zeros(T,2); % durable markup
IR_c_mu = zeros(T,2); % nondurable markup
IR_pid  = zeros(T,2); % durable inflation
IR_pic  = zeros(T,2); % nondurable inflation
IR_i    = zeros(T,2); % nominal interest rate
IR_h    = zeros(T,2); % total hours

IR_x_tfp    = zeros(T,2); % new durable expenditure
IR_c_tfp    = zeros(T,2); % nondurable expenditure
IR_s_tfp    = zeros(T,2); % replacement ratio
IR_d_mu_tfp = zeros(T,2); % durable markup
IR_c_mu_tfp = zeros(T,2); % nondurable markup
IR_z_tfp    = zeros(T,2); % TFP
IR_h_tfp    = zeros(T,2); % total hours


for ii = 1:2
    PI_S = adjcost(ii);
        
    %Obtain numerical derivatives of f
    num_eval
    
    temp = max(nf); 
    disp(['Solution accuracy = ' num2str(temp)])
    
    %First-order approximation
    [gx,hx] = gx_hx(nfy,nfx,nfyp,nfxp);
    
    eta = [0 5 0 0 0 0 0 0 0;
           1 0 0 0 0 0 0 0 0]';
           
    varshock = eta*eta';
    J=0;
    [sigy0,sigx0]=mom(gx,hx,varshock,J);
    J=1;
    [sigy1,sigx1]=mom(gx,hx,varshock,J);
    
    % Second moment analysis
    stdy0=sqrt(diag(sigy0));
    corry1=diag(sigy1)./diag(sigy0);
    corry0=sigy0./(stdy0*stdy0');
    
    disp(' ')
    disp(['std(durable)    = ' num2str(stdy0(3))])
    disp(['std(nondurable) = ' num2str(stdy0(1))])
    disp(['std(durable)/std(nondurable) = ' num2str(stdy0(3)/stdy0(1))])
    disp('autocorr      durable          nondurable')
    disp(['             ' num2str(corry1(3)) '          ' num2str(corry1(1))])
    
    % Common TFP shock
    x0 = [0 -0.01 0 0 0 0 0 0 0]; 
    %x0 = [0 0 0 0 0 0 0 0 0 1];
    [IR_tfp,IRy_tfp,IRx_tfp]=ir(gx,hx,x0,T);
    
    IR_x_tfp(:,ii)    =  IRy_tfp(:,3);            % new durable expenditure
    IR_c_tfp(:,ii)    =  IRy_tfp(:,1);            % nondurable expenditure
    IR_s_tfp(:,ii)    =  IRy_tfp(:,5);            % replacement ratio
    IR_h_tfp(:,ii)    =  IRy_tfp(:,8);            % total hours
    IR_d_mu_tfp(:,ii) =  IRy_tfp(:,14)-IRy_tfp(:,20); % durable markup
    IR_c_mu_tfp(:,ii) = -IRy_tfp(:,19);           % nondurable markup
    IR_z_tfp(:,ii)    =  IRx_tfp(:,2);            % TFP

        
    % Monetary policy shock
    v0   = tg; % interest rate shock to start with
    crit = 1;  % initial critical value
    iter = 1;  % initial value
    %----------------------------------------------%
    while (crit > 0.001) && (iter < 100)
        x0 = [v0 0 0 0 0 0 0 0 0];
        [IR,IRy,IRx]=ir(gx,hx,x0,T);
        crit = abs(IRx(2,3)-tg);
        v0 = v0*(tg/IRx(2,3));
        iter = iter + 1;
    end
    disp(['number of iterations: ' num2str(iter)])
    disp(['critical value for interest rate: ' num2str(crit)])
    
    % IRFs
    IR_x(:,ii)    =  IRy(:,3);            % new durable expenditure
    IR_c(:,ii)    =  IRy(:,1);            % nondurable expenditure
    IR_s(:,ii)    =  IRy(:,5);            % replacement ratio
    IR_h(:,ii)    =  IRy(:,8);            % total hours
    IR_d_mu(:,ii) =  IRy(:,14)-IRy(:,20); % durable markup
    IR_c_mu(:,ii) = -IRy(:,19);           % nondurable markup
    IR_i(:,ii)    =  IRy(:,13);           % nominal interest rate
    IR_pic(:,ii)  =  IRy(:,16);           % nondurable inflation
    IR_pid(:,ii)  =  IRy(:,17);           % durable inflation
    
end



%% PLOT
f1 = figure; % Set figure number for display
graphname1 = 'fig4';
% 3.1. Figure configuration
set(gcf, 'PaperUnits', 'inches') 
set(gcf, 'PaperOrientation', 'landscape');
papersize = get(gcf, 'PaperSize');
%------------- User configuration -------------%
width  = 10;  % Initialize a variable for width
height = 5;   % Initialize a variable for height
%----------------------------------------------%
bottom = (papersize(2)- height)/2;
left = (papersize(1)- width)/2;
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);


% Subplot 1: Durable expenditure
subplot(2,4,1)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'color','k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_x(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_x(:,2)]);

% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on;
%title('$$\hat{x}_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
title('New Durable Expenditure','FontSize',10,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%

% Subplot 2: Nondurable expenditure
subplot(2,4,2)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_c(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_c(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on;
%title('$$\hat{c}_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
title('Nondurable Expenditure','FontSize',10,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%

% Subplot 3: Hours worked
subplot(2,4,3)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_h(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_h(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on;
%title('$$\hat{h}_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
title('Hours','FontSize',10,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%

% Subplot 4: Replacement rate
subplot(2,4,4)
hold on; grid on;
plot(-1:T-1,100*SSN+0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[SSN;SSN*exp(IR_s(:,1))]);
h2 = plot(-1:T-1,100*[SSN;SSN*exp(IR_s(:,2))]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
legend([h1 h2],'low cost','high cost','Location','SouthEast');
legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on;
%title('$$s_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
title('Replacement Rate','FontSize',10,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percentage point','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%


% Subplot 5: Relative durable inflation
subplot(2,4,5)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_pid(:,1)-IR_pic(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_pid(:,2)-IR_pic(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');%[ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
%ylim([0 0.04])
box on;
%title('$$\hat{\pi}_{dt} - \hat{\pi}_{ct}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
title('New Durable Relative Inflation','FontSize',10,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%

% Subplot 6: Nondurable inflation
subplot(2,4,6)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_pic(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_pic(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
%ylim([0 0.04])
box on;
%title('$$\hat{\pi}_{ct}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
title('Nondurable Inflation','FontSize',10,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%


%Subplot 7: Durable price markup
subplot(2,4,7)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_d_mu(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_d_mu(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color', 'k');%[ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
%ylim([0 0.04])
box on
%title('$$\hat{\mu}_{dt}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
title('Durable Markup','FontSize',10,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%


%Subplot 8: Nominal interest rate
subplot(2,4,8)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_i(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_i(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'low replacement cost','high replacement cost','Location','NorthEast');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on;
%title('$$\hat{r}_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
title('Nominal Interest Rate','FontSize',10,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',10,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%


% 3.5. Save plot
cd Plot % in a subfolder "\Plot"
print(f1,'-dpdf', [graphname1]); 
print(f1,'-depsc2', [graphname1]); % not sure why not working...
cd ..






%% PLOT
f2 = figure; % Set figure number for display
graphname2 = 'figA1';
% 3.1. Figure configuration
set(gcf, 'PaperUnits', 'inches') 
set(gcf, 'PaperOrientation', 'landscape');
papersize = get(gcf, 'PaperSize');
%------------- User configuration -------------%
width  = 10;  % Initialize a variable for width
height = 5;   % Initialize a variable for height
%----------------------------------------------%
bottom = (papersize(2)- height)/2;
left = (papersize(1)- width)/2;
myfiguresize = [left, bottom, width, height];
set(gcf, 'PaperPosition', myfiguresize);


% New durable expenditure
subplot(2,3,1)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_x_tfp(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_x_tfp(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color', 'k');%[ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color', [0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on
title('$$\hat{x}_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%

subplot(2,3,2)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_c_tfp(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_c_tfp(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color', 'k');%[ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color', [0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on
title('$$\hat{c}_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%


subplot(2,3,3)
hold on; grid on;
plot(-1:T-1,100*SSN+0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[SSN;SSN*exp(IR_s_tfp(:,1))]);
h2 = plot(-1:T-1,100*[SSN;SSN*exp(IR_s_tfp(:,2))]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
legend([h1 h2],'low cost','high cost','Location','SouthEast');
legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on;
title('$$s_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percentage point','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%

% Subplot 3: Hours worked
subplot(2,3,4)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_h_tfp(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_h_tfp(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on;
title('$$\hat{h}_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%



subplot(2,3,5)
hold on; grid on;
plot(-1:T-1,0*(-1:T-1),'k','LineWidth',l_w)
h1 = plot(-1:T-1,100*[0;IR_z_tfp(:,1)]);
h2 = plot(-1:T-1,100*[0;IR_z_tfp(:,2)]);
% Other figure configuration details
%------------- User configuration -------------%
set(gca,'XLim',[-1 T-1],'XTickMode','auto','Layer','top')
set(h1,'LineStyle','-', 'LineWidth',  l_w2, 'Color','k');% [ 26, 118, 255]/255);
set(h2,'LineStyle','--', 'LineWidth', l_w2, 'Color',[0.5 0.5 0.5]);%[117,  23,  31]/255);
%legend([h1 h2],'Replace','No replace','Location','NorthWest');
%legend boxoff
set(gca,'XTick',[0:4:T-1]) % X tick data to plot
box on;
title('$$\hat{z}_{t}$$','FontSize',14,'FontWeight','Bold','Interpreter','Latex')
ylabel('Percent','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
xlabel('Period','FontSize',12,'FontWeight','Bold','Interpreter','Latex');
%----------------------------------------------%


% 3.5. Save plot
cd Plot % in a subfolder "\Plot"
print(f2,'-dpdf', [graphname2]); 
print(f2,'-depsc2', [graphname2]); % not sure why not working...
cd ..



